
#include "tn5250-config.h"

char *version_string = VERSION;
